<?php
/* $Id: nc_sub_class.class.php 2814 2009-02-11 12:25:03Z vadim $ */

class nc_Sub_Class extends nc_Essence {
  
  protected $core;
  protected $db;
  private $_current_id;
  
  /**
   * Constructor function
   */
  public function __construct () {
    // load parent constructor
    parent::__construct();
    
    // system superior object
    $this->core = nc_Core::getObject();
    // system db object
    if ( is_object($this->core->db) ) $this->db = $this->core->db;
  }
  
  /**
   * Get subclass data with system table flag from `Class` table
   *
   * @param Subdivision_ID, if not setted - using current value in query
   * @param bool use returned value as current subclass data
   * @param bool reset stored data in the static variable
   *
   * @return subclass data associative array
   */
  public function get_by_subdivision_id ($id = 0, $reset = false) {
    // call as static
    static $storage = array();
    
    // validate parameters
    $id = intval($id);
    if ( !$id && is_object($this->core->subdivision) ) {
      $id = $this->core->subdivision->get_current("Subdivision_ID");
    }
    
    if (!$id) return false;
    
    // check inited object
    if ( empty($storage[$id]) || $reset ) {
      
      $storage[$id] = $this->db->get_results("SELECT b.*, c.`System_Table_ID` AS sysTbl
      FROM `Sub_Class` AS b
      LEFT JOIN `Class` AS c ON b.`Class_ID` = c.`Class_ID`
      WHERE b.`Subdivision_ID` = '".$id."'
      ORDER BY b.`Checked`, b.`Priority`", ARRAY_A);
      
    }
    
    return $storage[$id];
  }
  
  /**
   * Set current subclass data by the id
   *
   * @param int subclass id
   * @param bool reset stored data in the static variable
   *
   * @return setted current cc id
   */
  public function set_current_by_id ($id) {
    
    // validate
    $id = intval($id);
    
    if ($id) {
      $this->current = $this->get_by_id($id, "", $reset);
      // set additional data
      $this->_current_id = $id;
      // inherit current data
      if ( in_array($this->essence, $this->inherit_essences) ) {
        $this->current = $this->inherit();
      }
      // return result
      return $this->current;
    }
    
    // reject
    return false; 
  }
  
  function inherit () {
    // get cc data associative array
    $cc_env = $this->get_current();

    if ($cc_env) {
      // inherit from Class
      $class_env = $this->core->component->get_by_id($cc_env["Class_ID"]);
      
      foreach ($class_env AS $key => $val) {
        if ($cc_env[$key]=="") $cc_env[$key] = $val;
      }

      if ($cc_env["NL2BR"] == -1) $cc_env["NL2BR"] = $class_env["NL2BR"];
      if ($cc_env["AllowTags"] == -1) $cc_env["AllowTags"] = $class_env["AllowTags"];
      if ($cc_env["UseCaptcha"] == -1) $cc_env["UseCaptcha"] = $class_env["UseCaptcha"];
    }

    // inherit from Subdivision
    $sub_env = $this->core->subdivision->get_current();

    if (!$cc_env["Read_Access_ID"]) $cc_env["Read_Access_ID"] = $sub_env["Read_Access_ID"];
    if (!$cc_env["Write_Access_ID"]) $cc_env["Write_Access_ID"] = $sub_env["Write_Access_ID"];
    if (!$cc_env["Edit_Access_ID"]) $cc_env["Edit_Access_ID"] = $sub_env["Edit_Access_ID"];
    if (!$cc_env["Subscribe_Access_ID"]) $cc_env["Subscribe_Access_ID"] = $sub_env["Subscribe_Access_ID"];
    if ( $this->core->modules->get_by_keyword("cache") ) {
      if (!$cc_env["Cache_Access_ID"]) $cc_env["Cache_Access_ID"] = $sub_env["Cache_Access_ID"];
      if (!$cc_env["Cache_Lifetime"]) $cc_env["Cache_Lifetime"] = $sub_env["Cache_Lifetime"];
    }
    if (!$cc_env["Moderation_ID"]) $cc_env["Moderation_ID"] = $sub_env["Moderation_ID"];

    return $cc_env;
  }
  
}

?>