<?php
/* $Id: nc_subdivision.class.php 2820 2009-02-12 08:52:18Z vadim $ */

class nc_Subdivision extends nc_Essence {
  
  protected $core;
  protected $db;
  
  /**
   * Constructor function
   */  
  public function __construct () {
    // load parent constructor
    parent::__construct();
    
    // system superior object
    $this->core = nc_Core::getObject();
    // system db object
    if ( is_object($this->core->db) ) $this->db = $this->core->db;
    
  }
  
  /**
   * Get subdivision data by the URI parameter
   *
   * @param URI string
   * @param bool use returned value as current catalogue data
   * @param bool reset stored data in the static variable
   *
   * @return subdivision data associative array
   */
  public function set_current_by_uri ($reset = false) {
    // call as static
    static $storage = array();
    
    // URI
    $uri = $this->core->url->get_parsed_url('path');
    
    // check inited object
    if ( empty($storage) || $reset ) {
      
      // find date in url
      preg_match("|
        / (\d{4}) /
        (?:
          (\d{2}) /
        )?
        (?:
          (\d{2}) /
        )?
      |x", $uri, $regs);
      // date found
      if ($regs) {
        // crop date symbols
        $uri = str_replace($regs[0], "/", $uri);
      }
    
      $storage = $this->db->get_row("SELECT * FROM `Subdivision` WHERE `Catalogue_ID` = '".intval($this->core->catalogue->get_current("Catalogue_ID"))."' AND `Hidden_URL` = '".$this->db->escape($uri)."'", ARRAY_A);
      
      // processing system fields
      $storage = $this->convert_system_vars($storage);

      // set current subdivision data
      $this->current = $storage;
      // inherit current data, only after then setted $this->current!
      $this->current = $this->inherit();
    }
    
    return $storage;
  }
  
  protected function inherit () {
    // get subdivision data and convert system fields 
    $sub_env = $this->get_current();

    $this->_level_count = 0;
    $this->_parent_tree[] = "";

    $this->_parent_tree[$this->_level_count] = $sub_env;
    $this->_level_count++;

    $parent_sub = $sub_env["Parent_Sub_ID"];
    
    while ($parent_sub) {
      $parent_sub_env = $this->get_by_id($parent_sub);

      if (!$sub_env["Template_ID"]) {
        $sub_env["Template_ID"] = $parent_sub_env["Template_ID"];
        $sub_env["TemplateSettings"] = $parent_sub_env["TemplateSettings"];
      }
      if (!$sub_env["Read_Access_ID"]) $sub_env["Read_Access_ID"] = $parent_sub_env["Read_Access_ID"];
      if (!$sub_env["Write_Access_ID"]) $sub_env["Write_Access_ID"] = $parent_sub_env["Write_Access_ID"];
      if (!$sub_env["Edit_Access_ID"]) $sub_env["Edit_Access_ID"] = $parent_sub_env["Edit_Access_ID"];
      if (!$sub_env["Subscribe_Access_ID"]) $sub_env["Subscribe_Access_ID"] = $parent_sub_env["Subscribe_Access_ID"];
      if ( $this->core->modules->get_by_keyword("cache") ) {
        if (!$sub_env["Cache_Access_ID"]) $sub_env["Cache_Access_ID"] = $parent_sub_env["Cache_Access_ID"];
        if (!$sub_env["Cache_Lifetime"]) $sub_env["Cache_Lifetime"] = $parent_sub_env["Cache_Lifetime"];
      }
      if (!$sub_env["Moderation_ID"]) $sub_env["Moderation_ID"] = $parent_sub_env["Moderation_ID"];

      $this->_parent_tree[$this->_level_count] = $parent_sub_env;
      $sub_env = InheritSystemFields ("Subdivision",$this->_parent_tree[$this->_level_count],$sub_env);

      $this->_level_count++;

      $parent_sub = $parent_sub_env["Parent_Sub_ID"];
    }

    $catalogue_env = $this->core->catalogue->get_by_id($sub_env["Catalogue_ID"]);

    $sub_env = InheritSystemFields ("Catalogue",$catalogue_env,$sub_env);

    if (!$sub_env["Template_ID"]) {
     $sub_env["Template_ID"] = $catalogue_env["Template_ID"];
     $sub_env["TemplateSettings"] = $catalogue_env["TemplateSettings"];
    }

    if (!$sub_env["Read_Access_ID"]) $sub_env["Read_Access_ID"] = $catalogue_env["Read_Access_ID"];
    if (!$sub_env["Write_Access_ID"]) $sub_env["Write_Access_ID"] = $catalogue_env["Write_Access_ID"];
    if (!$sub_env["Edit_Access_ID"]) $sub_env["Edit_Access_ID"] = $catalogue_env["Edit_Access_ID"];
    if (!$sub_env["Subscribe_Access_ID"]) $sub_env["Subscribe_Access_ID"] = $catalogue_env["Subscribe_Access_ID"];
    if ( $this->core->modules->get_by_keyword("cache") ) {
      if (!$sub_env["Cache_Access_ID"]) $sub_env["Cache_Access_ID"] = $catalogue_env["Cache_Access_ID"];
      if (!$sub_env["Cache_Lifetime"]) $sub_env["Cache_Lifetime"] = $catalogue_env["Cache_Lifetime"];
    }
    if (!$sub_env["Moderation_ID"]) $sub_env["Moderation_ID"] = $catalogue_env["Moderation_ID"];

    $this->_parent_tree[$this->_level_count] = $catalogue_env;
 
    return $sub_env;
  }
  
  public function get_parent_tree () {
    
    if ($this->_parent_tree) {
      return $this->_parent_tree;
    }
    else {
      $this->inherit();
      return $this->_parent_tree;
    }
  
  }
  
  public function get_level_count () {
    
    if ($this->_level_count) {
      return $this->_level_count;
    }
    else {
      $this->inherit();
      return $this->_level_count;
    }
  
  }
  
}


?>