<?php
/* $Id: nc_event.class.php 2908 2009-02-19 16:26:23Z vadim $ */

class nc_Event extends nc_System {
  
  protected $core;
  private $_binded_obj, $_events_arr;
  
  public function __construct ($core) {
    // load parent constructor
    parent::__construct();
    
    // system superior object
    if ( get_class($core)=="nc_Core" ) $this->core = $core;
    
    // collect objects for events
    $this->_binded_obj = array();
    
    // allowed events
    $this->_events_arr = array(
      // drop actions
      "dropCatalogue",
      "dropSubdivision",
      "dropSubClass",
      "dropClass",
      "dropMessages"
    );
  }

  /**
   * Add object to the listen mode
   *
   * @param object examine object
   */
  public function bind (&$object, $events_remap_arr = false) {
    // add object in array
    if ( !in_array($object, $this->_binded_obj) ) {
      // set empty remap array
      if (!$events_remap_arr) $events_remap_arr = array();
      // bind object with remap array
      $this->_binded_obj[] = array('object' => $object, 'remap' => $events_remap_arr);
    }
    return;
  }
  
  /**
   * Event processor
   * call objects function for current event
   *
   */
  public function execute () {
    // get function args
    $args = func_get_args();
    // check args
    if ( empty($args) || empty($this->_binded_obj) ) return false;
    // event
    $event = array_shift($args);
    // check event
    if ( !( $event && in_array($event, $this->_events_arr) ) ) {
      return false;
    }
    // call objects observer function
    foreach ($this->_binded_obj as $object) {
      // check remaping
      if ( !empty($object['remap']) ) {
        // remap event method
        if ($object['remap'][$event]) $event = $object['remap'][$event];
      }
      // check and execute observer method
      if ( is_callable(  array($object['object'], $event) ) ) {
        call_user_func_array( array($object['object'], $event), $args );
      }
    }
    return;
  }
  
}

?>