<?php
/* $Id: nc_modules.class.php 3010 2009-03-12 12:52:36Z vadim $ */

class nc_Modules extends nc_System {
  
  protected $core;
  protected $db;
  
  public function __construct ($core) {
    // load parent constructor
    parent::__construct();
    
    // system superior object
    if ( get_class($core)=="nc_Core" ) $this->core = $core;
    // system db object
    if ( is_object($this->core->db) ) $this->db = $this->core->db;
  }
  
  public function get_data () {
    // set as static
    static $all_modules_data = array();
    // get data from base, once
    if ( empty($all_modules_data) ) {
      $all_modules_data = $this->db->get_results("SELECT * FROM `Module`", ARRAY_A);
    }
    // result data array
    return !empty($all_modules_data) ? $all_modules_data : false;
  }
  
  /**
   * Check installed module by keyword
   *
   * @param string module keyword
   * @param bool `Installed` column
   *
   * @return array module data or false
   */
  public function get_by_keyword ($keyword, $installed = true) {
    // get all modules data
    $all_modules_data = $this->get_data();
    // `Module` table empty
    if ( empty($all_modules_data) ) return false;
    // walk on array
    foreach ($all_modules_data AS $module_data) {
      if ($module_data['Keyword']!=$keyword) continue;
      if ($installed) {
        if ($module_data['Installed']) {
          return $module_data;
        }
        else {
          return false;
        }
      }
      return $module_data;
    }
    
    return false;
  }
  
  public function load_env ($language = "", $only_inside_admin = false, $reload = false) {
    // set static variable
    static $result = array();

    // check
    if ( empty($result) || $reload ) {  
      // load check_module_by_keyword() function
      require_once ($this->core->INCLUDE_FOLDER."s_common.inc.php");
      
      $modules_data = $this->get_data();
       
    	if ( empty($modules_data) ) return false;
      
      // determine language
      if ( !$language && is_object($this->core->catalogue) ) {
        $language = $this->core->catalogue->get_current("Language");
      }

      if (!$language) return false;

      foreach ($modules_data as $row) {
        // load modules marked as "inside_admin" if only_inside_admin == true
        if ($only_inside_admin && !$row['Inside_Admin']) continue;
        // module keyword
        $keyword = $row['Keyword'];
        // include language file
        if ( is_file($this->core->MODULE_FOLDER.$keyword."/".$language.".lang.php") ) {
          require_once ($this->core->MODULE_FOLDER.$keyword."/".$language.".lang.php");
        }
        else {
          require_once ($this->core->MODULE_FOLDER.$keyword."/en.lang.php");
        }
        // include the module itself
        if ( is_file($this->core->MODULE_FOLDER.$keyword."/function.inc.php") ) {
          require_once ($this->core->MODULE_FOLDER.$keyword."/function.inc.php");
        }
      }
      // MODULE_VARS
      $result = $this->get_module_vars();
    }
    // return result
    return $result;
  }
  
  public function get_module_vars () {
    // set static variable
    static $result;
    // check
    if ( !isset($result) ) {  
      $modules_data = $this->get_data();
         
      if ( empty($modules_data) ) return false;
      
      foreach ($modules_data as $row) {
        // module keyword and params
        $keyword = $row['Keyword'];
        $params = $row['Parameters'];

        // parse module params
        $query_string = str_replace( array("\n", "\r\n"), "&", $params);
        parse_str($query_string, $result[$keyword]);
        
        // modules parameters
        if ( !empty($result[$keyword]) ) {
          foreach ($result[$keyword] as $key => $value) {
            $result[$keyword][$key] = trim($value);
          }
        }
      }
    }
    // return result
    return $result;
  }
  
  public function get_vars ($module, $item = "") {
    // get data for all modules
    $modules_vars = $this->get_module_vars();
    // vars for this module
    if ( !empty($modules_vars[$module]) ) {
      // if item requested return item value
      if ($item) {
        return is_array($modules_vars[$module]) && array_key_exists($item, $modules_vars[$module]) ? $modules_vars[$module][$item] : false;
      }
      else {
        return $modules_vars[$module];
      }
    }
    // default
    return false;
  }

}

?>