<?php
/* $Id: nc_url.class.php 2968 2009-03-04 09:07:23Z vadim $ */

class nc_Url extends nc_System {

  protected $core;
  private $_parsed_url;
  
  public function __construct ($core) {
    // load parent constructor
    parent::__construct();
    
    // system superior object
    if ( get_class($core)=="nc_Core" ) $this->core = $core;
  }
  
  public function build_url ($query_arr) {
    // build query string
    if ( !empty($query_arr) ) {
      return urldecode( http_build_query($query_arr, "", "&") );
    }
    // no result
    return false;
  }
  
  public function parse_url () {
    // system url
    $url = "http://".getenv("HTTP_HOST").getenv("REQUEST_URI");
    // parse entire url
    $parsed_url = @parse_url($url);
    
    // validate query parameter
    if ($parsed_url['query']) {
      parse_str($parsed_url['query'], $parsed_query_arr);
      // validate
      $parsed_query_arr = $this->core->input->clear_system_vars($parsed_query_arr);
      // in error_document $_GET is empty, so set them at this line
      $_GET = $parsed_query_arr ? $parsed_query_arr : array();
      // build new query
      $parsed_url['query'] = $this->build_url($parsed_query_arr);
    }

    // for other functions
    $this->_parsed_url = $parsed_url;
    
    // return array
    return $this->_parsed_url;
  }
  
  public function get_parsed_url ($item = "") {
    
    if ( empty($this->_parsed_url) ) return false;
    
    if ( $item ) {
      return array_key_exists($item, $this->_parsed_url) ? $this->_parsed_url[$item] : "";
    }
    else {
      return $this->_parsed_url;
    }
    
  }
  
  public function set_parsed_url_item ($item, $value) {
    
    if ( empty($this->_parsed_url) ) return false;
    
    $this->_parsed_url[$item] = $value;
    
    return true;
  }
  
  public function get_uri_date ($timestamp = false) {
    // find date in url
    preg_match("|
      / (\d{4}) /
      (?:
        (\d{2}) /
      )?
      (?:
        (\d{2}) /
      )?
    |x", $this->get_parsed_url('path'), $regs);
    // date found
    if ($regs) {
      array_shift($regs);
      $date = join("-", $regs);
    }
    // convert to the timestamp
    if ($timestamp) $date = strtotime($date);
    // return result date
    return $date ? $date : false;
  }
  
  public function source_url () {
    // compile client source url
    return $this->_parsed_url['scheme']."://".
      ($this->_parsed_url['user'] ? $this->_parsed_url['user'] : "").
      ($this->_parsed_url['pass'] ? ":".$this->_parsed_url['pass'] : "").
      (($this->_parsed_url['user'] || $this->_parsed_url['pass']) ? "@" : "").
      $this->_parsed_url['host'].
      ($this->_parsed_url['port'] ? ":".$this->_parsed_url['port'] : "").
      $this->_parsed_url['path'];
  }

}

?>